@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: contravariant
 version: 1.4
-id: contravariant-1.4-7b1149a75def92c79deb23a86e0b36cb
-key: contr_7dAWB2x4yN9BZDQgwGJsfm
+id: contravariant-1.4-6e8bc7cb2457226c1a88750295477d07
+key: contr_KM4fAXZBaqx6OO468wTyg6
 license: BSD3
 copyright: Copyright (C) 2007-2015 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -23,14 +23,14 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/contravariant-1.4
 library-dirs: /usr/lib/ghc-7.10.3/site-local/contravariant-1.4
 data-dir: /usr/share/arm-linux-ghc-7.10.3/contravariant-1.4
-hs-libraries: HScontravariant-1.4-7dAWB2x4yN9BZDQgwGJsfm
+hs-libraries: HScontravariant-1.4-KM4fAXZBaqx6OO468wTyg6
 depends:
     StateVar-1.1.0.3-dfbaaa5b80efc1d36dff08b16817e21d
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
+    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
-    void-0.7.1-5ad9ec6793ffb57ac26a200023a4290d
+    void-0.7.1-5298c6b3a32576797627b9b87532f9cb
 haddock-interfaces: /usr/share/doc/haskell-contravariant/html/contravariant.haddock
 haddock-html: /usr/share/doc/haskell-contravariant/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
